@@ -21,16 +21,9 @@
 #include <sstream>
 #include <vector>
 
-//#include "model/HighsModel.h"
-//#include "HConfig.h"
-//#include "io/HighsIO.h"
-//#include "lp_data/HConst.h"
 #include "lp_data/HighsSolution.h"
 #include "util/stringutil.h"
 
-const double kHighsDoubleTolerance = 1e-13;
-const double kGlpsolDoubleTolerance = 1e-12;
-
 void analyseModelBounds(const HighsLogOptions& log_options, const char* message,
                         HighsInt numBd, const std::vector<double>& lower,
                         const std::vector<double>& upper) {
@@ -230,12 +223,12 @@ void writeModelSolution(FILE* file, const HighsLp& lp,
     for (HighsInt i = 0; i < lp.num_col_; ++i)
       objective_function_value += lp.col_cost_[i] * solution.col_value[i];
     std::array<char, 32> objStr = highsDoubleToString(
-        (double)objective_function_value, kHighsDoubleTolerance);
+        (double)objective_function_value, kHighsSolutionValueToStringTolerance);
     fprintf(file, "Objective %s\n", objStr.data());
     fprintf(file, "# Columns %" HIGHSINT_FORMAT "\n", lp.num_col_);
     for (HighsInt ix = 0; ix < lp.num_col_; ix++) {
-      std::array<char, 32> valStr =
-          highsDoubleToString(solution.col_value[ix], kHighsDoubleTolerance);
+      std::array<char, 32> valStr = highsDoubleToString(
+          solution.col_value[ix], kHighsSolutionValueToStringTolerance);
       // Create a column name
       ss.str(std::string());
       ss << "C" << ix;
@@ -244,8 +237,8 @@ void writeModelSolution(FILE* file, const HighsLp& lp,
     }
     fprintf(file, "# Rows %" HIGHSINT_FORMAT "\n", lp.num_row_);
     for (HighsInt ix = 0; ix < lp.num_row_; ix++) {
-      std::array<char, 32> valStr =
-          highsDoubleToString(solution.row_value[ix], kHighsDoubleTolerance);
+      std::array<char, 32> valStr = highsDoubleToString(
+          solution.row_value[ix], kHighsSolutionValueToStringTolerance);
       // Create a row name
       ss.str(std::string());
       ss << "R" << ix;
@@ -265,8 +258,8 @@ void writeModelSolution(FILE* file, const HighsLp& lp,
     }
     fprintf(file, "# Columns %" HIGHSINT_FORMAT "\n", lp.num_col_);
     for (HighsInt ix = 0; ix < lp.num_col_; ix++) {
-      std::array<char, 32> valStr =
-          highsDoubleToString(solution.col_dual[ix], kHighsDoubleTolerance);
+      std::array<char, 32> valStr = highsDoubleToString(
+          solution.col_dual[ix], kHighsSolutionValueToStringTolerance);
       ss.str(std::string());
       ss << "C" << ix;
       const std::string name = have_col_names ? lp.col_names_[ix] : ss.str();
@@ -274,8 +267,8 @@ void writeModelSolution(FILE* file, const HighsLp& lp,
     }
     fprintf(file, "# Rows %" HIGHSINT_FORMAT "\n", lp.num_row_);
     for (HighsInt ix = 0; ix < lp.num_row_; ix++) {
-      std::array<char, 32> valStr =
-          highsDoubleToString(solution.row_dual[ix], kHighsDoubleTolerance);
+      std::array<char, 32> valStr = highsDoubleToString(
+          solution.row_dual[ix], kHighsSolutionValueToStringTolerance);
       ss.str(std::string());
       ss << "R" << ix;
       const std::string name = have_row_names ? lp.row_names_[ix] : ss.str();
@@ -380,8 +373,9 @@ void writeSolutionFile(FILE* file, const HighsOptions& options,
                             have_basis, basis.row_status);
     fprintf(file, "\nModel status: %s\n",
             utilModelStatusToString(model_status).c_str());
-    std::array<char, 32> objStr = highsDoubleToString(
-        (double)info.objective_function_value, kHighsDoubleTolerance);
+    std::array<char, 32> objStr =
+        highsDoubleToString((double)info.objective_function_value,
+                            kHighsSolutionValueToStringTolerance);
     fprintf(file, "\nObjective value: %s\n", objStr.data());
   } else if (style == kSolutionStyleGlpsolRaw ||
              style == kSolutionStyleGlpsolPretty) {
@@ -400,8 +394,8 @@ void writeGlpsolCostRow(FILE* file, const bool raw, const bool is_mip,
                         const double objective_function_value) {
   if (raw) {
     double double_value = objective_function_value;
-    std::array<char, 32> double_string =
-        highsDoubleToString(double_value, kGlpsolDoubleTolerance);
+    std::array<char, 32> double_string = highsDoubleToString(
+        double_value, kGlpsolSolutionValueToStringTolerance);
     // Last term of 0 for dual should (also) be blank when not MIP
     fprintf(file, "i %d %s%s%s\n", (int)row_id, is_mip ? "" : "b ",
             double_string.data(), is_mip ? "" : " 0");
@@ -653,7 +647,7 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     }
     double double_value = has_objective ? info.objective_function_value : 0;
     std::array<char, 32> double_string =
-        highsDoubleToString(double_value, kHighsDoubleTolerance);
+        highsDoubleToString(double_value, kHighsSolutionValueToStringTolerance);
     fprintf(file, " %s\n", double_string.data());
   }
   if (!raw) {
@@ -685,8 +679,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
       if (is_mip) {
         // Complete the line if for a MIP
         double double_value = solution.row_value[iRow];
-        std::array<char, 32> double_string =
-            highsDoubleToString(double_value, kHighsDoubleTolerance);
+        std::array<char, 32> double_string = highsDoubleToString(
+            double_value, kHighsSolutionValueToStringTolerance);
         fprintf(file, "%s\n", double_string.data());
         continue;
       }
@@ -734,8 +728,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     if (raw) {
       fprintf(file, "%s ", status_char.c_str());
       double double_value = solution.row_value[iRow];
-      std::array<char, 32> double_string =
-          highsDoubleToString(double_value, kHighsDoubleTolerance);
+      std::array<char, 32> double_string = highsDoubleToString(
+          double_value, kHighsSolutionValueToStringTolerance);
       fprintf(file, "%s ", double_string.data());
     } else {
       fprintf(file, "%s ", status_text.c_str());
@@ -752,8 +746,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     if (have_dual) {
       if (raw) {
         double double_value = solution.row_dual[iRow];
-        std::array<char, 32> double_string =
-            highsDoubleToString(double_value, kHighsDoubleTolerance);
+        std::array<char, 32> double_string = highsDoubleToString(
+            double_value, kHighsSolutionValueToStringTolerance);
         fprintf(file, "%s", double_string.data());
       } else {
         // If the row is known to be basic, don't print the dual
@@ -800,8 +794,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
       fprintf(file, "%s%d ", line_prefix.c_str(), (int)(iCol + 1));
       if (is_mip) {
         double double_value = solution.col_value[iCol];
-        std::array<char, 32> double_string =
-            highsDoubleToString(double_value, kHighsDoubleTolerance);
+        std::array<char, 32> double_string = highsDoubleToString(
+            double_value, kHighsSolutionValueToStringTolerance);
         fprintf(file, "%s\n", double_string.data());
         continue;
       }
@@ -852,8 +846,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     if (raw) {
       fprintf(file, "%s ", status_char.c_str());
       double double_value = solution.col_value[iCol];
-      std::array<char, 32> double_string =
-          highsDoubleToString(double_value, kHighsDoubleTolerance);
+      std::array<char, 32> double_string = highsDoubleToString(
+          double_value, kHighsSolutionValueToStringTolerance);
       fprintf(file, "%s ", double_string.data());
     } else {
       fprintf(file, "%s ", status_text.c_str());
@@ -870,8 +864,8 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     if (have_dual) {
       if (raw) {
         double double_value = solution.col_dual[iCol];
-        std::array<char, 32> double_string =
-            highsDoubleToString(double_value, kHighsDoubleTolerance);
+        std::array<char, 32> double_string = highsDoubleToString(
+            double_value, kHighsSolutionValueToStringTolerance);
         fprintf(file, "%s", double_string.data());
       } else {
         // If the column is known to be basic, don't print the dual
@@ -920,13 +914,11 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
   fprintf(file, "        max.rel.err = %.2e on row %d\n", relative_error_value,
           absolute_error_index == 0 ? 0 : (int)relative_error_index);
   fprintf(file, "%8s%s\n", "",
-          relative_error_value <= kGlpsolHighQuality
-              ? "High quality"
-              : relative_error_value <= kGlpsolMediumQuality
-                    ? "Medium quality"
-                    : relative_error_value <= kGlpsolLowQuality
-                          ? "Low quality"
-                          : "PRIMAL SOLUTION IS WRONG");
+          relative_error_value <= kGlpsolHighQuality     ? "High quality"
+          : relative_error_value <= kGlpsolMediumQuality ? "Medium quality"
+          : relative_error_value <= kGlpsolLowQuality
+              ? "Low quality"
+              : "PRIMAL SOLUTION IS WRONG");
   fprintf(file, "\n");
 
   // Primal infeasibility
@@ -949,13 +941,11 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
               ? (int)relative_error_index
               : (int)(relative_error_index - lp.num_col_));
   fprintf(file, "%8s%s\n", "",
-          relative_error_value <= kGlpsolHighQuality
-              ? "High quality"
-              : relative_error_value <= kGlpsolMediumQuality
-                    ? "Medium quality"
-                    : relative_error_value <= kGlpsolLowQuality
-                          ? "Low quality"
-                          : "PRIMAL SOLUTION IS INFEASIBLE");
+          relative_error_value <= kGlpsolHighQuality     ? "High quality"
+          : relative_error_value <= kGlpsolMediumQuality ? "Medium quality"
+          : relative_error_value <= kGlpsolLowQuality
+              ? "Low quality"
+              : "PRIMAL SOLUTION IS INFEASIBLE");
   fprintf(file, "\n");
 
   if (have_dual) {
@@ -971,13 +961,11 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
     fprintf(file, "        max.rel.err = %.2e on column %d\n",
             relative_error_value, (int)relative_error_index);
     fprintf(file, "%8s%s\n", "",
-            relative_error_value <= kGlpsolHighQuality
-                ? "High quality"
-                : relative_error_value <= kGlpsolMediumQuality
-                      ? "Medium quality"
-                      : relative_error_value <= kGlpsolLowQuality
-                            ? "Low quality"
-                            : "DUAL SOLUTION IS WRONG");
+            relative_error_value <= kGlpsolHighQuality     ? "High quality"
+            : relative_error_value <= kGlpsolMediumQuality ? "Medium quality"
+            : relative_error_value <= kGlpsolLowQuality
+                ? "Low quality"
+                : "DUAL SOLUTION IS WRONG");
     fprintf(file, "\n");
 
     // Dual infeasibility
@@ -1001,13 +989,11 @@ void writeGlpsolSolution(FILE* file, const HighsOptions& options,
                 ? (int)relative_error_index
                 : (int)(relative_error_index - lp.num_col_));
     fprintf(file, "%8s%s\n", "",
-            relative_error_value <= kGlpsolHighQuality
-                ? "High quality"
-                : relative_error_value <= kGlpsolMediumQuality
-                      ? "Medium quality"
-                      : relative_error_value <= kGlpsolLowQuality
-                            ? "Low quality"
-                            : "DUAL SOLUTION IS INFEASIBLE");
+            relative_error_value <= kGlpsolHighQuality     ? "High quality"
+            : relative_error_value <= kGlpsolMediumQuality ? "Medium quality"
+            : relative_error_value <= kGlpsolLowQuality
+                ? "Low quality"
+                : "DUAL SOLUTION IS INFEASIBLE");
     fprintf(file, "\n");
   }
   fprintf(file, "End of output\n");
